; The CMD file.
;
; Two parts: 1. Command definition and  2. State entry
; (state entry is after the commands def section)
;
; 1. Command definition
; ---------------------
; Note: The commands are CASE-SENSITIVE, and so are the command names.
; The eight directions are:
;   B, DB, D, DF, F, UF, U, UB     (all CAPS)
;   corresponding to back, down-back, down, downforward, etc.
; The six buttons are:
;   a, b, c, x, y, z               (all lower case)
;   In default key config, abc are are the bottom, and xyz are on the
;   top row. For 2 button characters, we recommend you use a and b.
;   For 6 button characters, use abc for kicks and xyz for punches.
;
; Each [Command] section defines a command that you can use for
; state entry, as well as in the CNS file.
; The command section should look like:
;
;   [Command]
;   name = some_name
;   command = the_command
;   time = time (optional)
;   buffer.time = time (optional)
;
; - some_name
;   A name to give that command. You'll use this name to refer to
;   that command in the state entry, as well as the CNS. It is case-
;   sensitive (QCB_a is NOT the same as Qcb_a or QCB_A).
;
; - command
;   list of buttons or directions, separated by commas. Each of these
;   buttons or directions is referred to as a "symbol".
;   Directions and buttons can be preceded by special characters:
;   slash (/) - means the key must be held down
;          egs. command = /D       ;hold the down direction
;               command = /DB, a   ;hold down-back while you press a
;   tilde (~) - to detect key releases
;          egs. command = ~a       ;release the a button
;               command = ~D, F, a ;release down, press fwd, then a
;          If you want to detect "charge moves", you can specify
;          the time the key must be held down for (in game-ticks)
;          egs. command = ~30a     ;hold a for at least 30 ticks, then release
;   dollar ($) - Direction-only: detect as 4-way
;          egs. command = $D       ;will detect if D, DB or DF is held
;               command = $B       ;will detect if B, DB or UB is held
;   plus (+) - Buttons only: simultaneous press
;          egs. command = a+b      ;press a and b at the same time
;               command = x+y+z    ;press x, y and z at the same time
;   greater-than (>) - means there must be no other keys pressed or released
;                      between the previous and the current symbol.
;          egs. command = a, >~a   ;press a and release it without having hit
;                                  ;or released any other keys in between
;   You can combine the symbols:
;     eg. command = ~30$D, a+b     ;hold D, DB or DF for 30 ticks, release,
;                                  ;then press a and b together
;
;   Note: Successive direction symbols are always expanded in a manner similar
;         to this example:
;           command = F, F
;         is expanded when MUGEN reads it, to become equivalent to:
;           command = F, >~F, >F
;
;   It is recommended that for most "motion" commads, eg. quarter-circle-fwd,
;   you start off with a "release direction". This makes the command easier
;   to do.
;
; - time (optional)
;   Time allowed to do the command, given in game-ticks. The default
;   value for this is set in the [Defaults] section below. A typical
;   value is 15.
;
; - buffer.time (optional)
;   Time that the command will be buffered for. If the command is done
;   successfully, then it will be valid for this time. The simplest
;   case is to set this to 1. That means that the command is valid
;   only in the same tick it is performed. With a higher value, such
;   as 3 or 4, you can get a "looser" feel to the command. The result
;   is that combos can become easier to do because you can perform
;   the command early. Attacks just as you regain control (eg. from
;   getting up) also become easier to do. The side effect of this is
;   that the command is continuously asserted, so it will seem as if
;   you had performed the move rapidly in succession during the valid
;   time. To understand this, try setting buffer.time to 30 and hit
;   a fast attack, such as KFM's light punch.
;   The default value for this is set in the [Defaults] section below. 
;   This parameter does not affect hold-only commands (eg. /F). It
;   will be assumed to be 1 for those commands.
;
; If you have two or more commands with the same name, all of them will
; work. You can use it to allow multiple motions for the same move.
;
; Some common commands examples are given below.
;
; [Command] ;Quarter circle forward + x
; name = "QCF_x"
; command = ~D, DF, F, x
;
; [Command] ;Half circle back + a
; name = "HCB_a"
; command = ~F, DF, D, DB, B, a
;
; [Command] ;Two quarter circles forward + y
; name = "2QCF_y"
; command = ~D, DF, F, D, DF, F, y
;
; [Command] ;Tap b rapidly
; name = "5b"
; command = b, b, b, b, b
; time = 30
;
; [Command] ;Charge back, then forward + z
; name = "charge_B_F_z"
; command = ~60$B, F, z
; time = 10
;
; [Command] ;Charge down, then up + c
; name = "charge_D_U_c"
; command = ~60$D, U, c
; time = 10


;-| Button Remapping |-----------------------------------------------------
; This section lets you remap the player's buttons (to easily change the
; button configuration). The format is:
;   old_button = new_button
; If new_button is left blank, the button cannot be pressed.
[Remap]
x = x
y = y
z = z
a = a
b = b
c = c
s = s

;-| Default Values |-------------------------------------------------------
[Defaults]
; Default value for the "time" parameter of a Command. Minimum 1.
command.time = 15

; Default value for the "buffer.time" parameter of a Command. Minimum 1,
; maximum 30.
command.buffer.time = 1

;--------------------
;AI activation
;--------------------

[Command]
name = "ai"
command = U, D, B, F, U, a, F, b, U, F, y, z, F
time = 1
[Command]
name = "ai"
command = F, b, U, F, y, z, F, U, D, B, F, U, a
time = 1
[Command]
name = "ai"
command = a, F, b, U, D, B, F, U, B, F, y, z, F, x
time = 1
[Command]
name = "ai"
command = c, a, F, z, U, F, y, z, F, x, D, B, F, U, B
time = 1
[Command]
name = "ai"
command = z, c, U, F, c, U, F, D, F, x, z, c, z, c, z, c
time = 1
[Command]
name = "ai"
command = z, c, U, F, c, U, F, U, F, y, z, F, x, D
time = 1
[Command]
name = "ai"
command = z ,c ,z ,c ,z ,c ,z ,c ,z ,c ,z ,U ,F ,c ,U
time = 1
[Command]
name = "ai"
command = z, c, U, F, U, F, y, z, F, x, D, a, F, z, U
time = 1
[Command]
name = "ai"
command = z, c, z, F, B, U, D, F, DF, z, U, c, U, F, D
time = 1
[Command]
name = "ai"
command = z, c, D, F, U, DF ,y , z+c, F, x, D, a, F, z, U
time = 1
[Command]
name = "ai"
command = F, x, D, a, F, z, U, z, c, D, F, U, DF, y, z+c
time = 1
[Command]
name = "ai"
command = z, c, U, F, U, D, U, c, z, z+b, F, y, z, F, x, D
time = 1
[Command]
name = "ai"
command = z, c, U, F, c, U, F, U, F, y, z, F, x, D, z, c
time = 1
[Command]
name = "ai"
command = c,z,c,U,F,c,U,F,D,F,x+z,c,z,
time = 1
[Command]
name = "ai"
command = z,c,U,F,c,U,z,F,x,D,a,F,z,U,F,U,F,y,z,F,x,D,z,c,z,c,z
time = 1
[Command]
name = "ai"
command = z,c,U,F,c,U,F,U,F,y,z,F,x,D,b,c,a,x
time = 1
[Command]
name = "ai"
command = z,c,F,y,z,F,F,x,D,b,c,a,x,D,z,c,z,c,z
time = 1
[Command]
name = "ai"
command = c,z,c,U,F,c,U,F,c,z
time = 1
[Command]
name = "ai"
command = z,c,U,F,c,U,z,x,D,a,F,z,U,F,U,F,y,z,F
time = 1
[Command]
name = "ai"
command = z,c,U,U,F,c,U,F,U,F,c,U,F,U,F,y,z,D,F,x+z
time = 1
[Command]
name = "ai"
command = z,c,D,F,U,DF,y,z+c,F,z,c,D,F,U
time = 1
[Command]
name = "ai"
command = F,x,D,a,F,z,U,DF,y,z+c,x,D,a,F,z,U
time = 1
[Command]
name = "ai"
command = z,c,U,F,U,D,U,c,z,D,a,F,z,U,y,z,F,x,D,z,c
time = 1
[Command]
name = "ai"
command = z+b,F,y,z,F,x,z,c,U,F,c,U,F,U,F,z,c,z
time = 1
[Command]
name = "ai"
command = F,U,c,x,F,U,c,x,F,U,c,x,F,U,c,x,FU,c+x
time = 1
[Command]
name = "ai"
command = c,z,c,U,F,c,U,F,D,F,x+z,c,z,c,U,F,U,F,y
time = 1
[Command]
name = "ai"
command = D,a,F,z,U,F,U,F,y,z,c,U,F,c,U,z,F,x
time = 1
[Command]
name = "ai"
command = z,c,U,F,z,F,x,D,b,c,a,x,D
time = 1
[Command]
name = "ai"
command = z,c,F,y,z,F,F,x,z,c,z,c,z,x,D,b,c,a
time = 1
[Command]
name = "ai"
command = c,z,c,U,F,c,U,U,F,c,U,z,F,x,z,F,F
time = 1
[Command]
name = "ai"
command = D,a,F,z,U,F,U,F,y,x+z,c,z,c,U,F,U,F,y+z
time = 1
[Command]
name = "ai"
command = z,c,U,F,z,F,x,D,b,c,a,x,D,D,b,c,a
time = 1
[Command]
name = "ai"
command = z,c,F,y,z,F,F,x,z,c,F,D,F,c,z,c,z,x
time = 1
[Command]
name = "ai"
command = z,c,D,y,z+c,F,z,c,D,F,U,F,U,DF
time = 1
[Command]
name = "ai"
command = F,x,D,a,F,z,x,D,a,F,z,UD,a,F,z,U
time = 1
[Command]
name = "ai"
command = z,c,U,F,U,D,U,U,DF,y,z+c,c,z,y,z,F,x,D,z,c
time = 1
[Command]
name = "ai"
command = z+b,F,y,z,F,U,F,z,c,z,F,x,z,c,U,F,c,U
time = 1
[Command]
name = "ai"
command = F,U,c,x,F,U,c,x,F,U,c,x,F,c,U,F,D,F
time = 1
[Command]
name = "ai"
command = c,z,c,U,F,x+z,c,U,c,x,FU,c+z,c,U,F,U,F,y
time = 1
[Command]
name = "ai"
command = F,z,c,z,F,x,z,c,U,F,c,U,x,FU,c+z,c,U,F,U,F,y
time = 1
[Command]
name = "ai"
command = F,U,c,x,F,U,c,x,F,F,D,F,z+b,F,y,z,F,U
time = 1
[Command]
name = "ai"
command = c,z,c,U,F,U,c,x,F,c,U,x+z,c,U,c,z,x,a
time = 1


;-----
;HUMAN
;-----


[Command]
name = "mic"
command = ~D, DF, F, x+y
time = 20

[Command]
name = "mic"
command = ~D, DF, F, x+z
time = 20

[Command]
name = "mic"
command = ~D, DF, F, y+z
time = 20

[Command]
name = "puppy"
command = ~D, DF, F, a+b
time = 20

[Command]
name = "puppy"
command = ~D, DF, F, a+c
time = 20

[Command]
name = "puppy"
command = ~D, DF, F, b+c
time = 20

[Command]
name = "rockette"
command = ~D, DB, B, x+y
time = 20

[Command]
name = "rockette"
command = ~D, DB, B, x+z
time = 20

[Command]
name = "rockette"
command = ~D, DB, B, y+z
time = 20

[Command]
name = "fatal"
command = ~D, DB, B, a+b
time = 20

[Command]
name = "fatal"
command = ~D, DB, B, a+c
time = 20

[Command]
name = "fatal"
command = ~D, DB, B, b+c
time = 20

;-| Special Motions |------------------------------------------------------
[Command]
name = "cellx"
command = ~D, DF, F, x

[Command]
name = "celly"
command = ~D, DF, F, y

[Command]
name = "cellz"
command = ~D, DF, F, z

[Command]
name = "twistx"
command = ~D, DB, B, x

[Command]
name = "twisty"
command = ~D, DB, B, y

[Command]
name = "twistz"
command = ~D, DB, B, z

[Command]
name = "multia"
command = ~D, DF, F, a

[Command]
name = "multib"
command = ~D, DF, F, b

[Command]
name = "multic"
command = ~D, DF, F, c

[Command]
name = "risinga"
command = ~D, DB, B, a

[Command]
name = "risingb"
command = ~D, DB, B, b

[Command]
name = "risingc"
command = ~D, DB, B, c

;-| Double Tap |-----------------------------------------------------------

;power1
[Command]
name="powb"
command=/b
time=1

;power1
[Command]
name="powy"
command=/y
time=1

[Command]
name = "FF"     ;Required (do not remove)
command = F, F
time = 10

[Command]
name = "BB"     ;Required (do not remove)
command = B, B
time = 10

;-| 2/3 Button Combination |-----------------------------------------------
[Command]
name = "recovery";Required (do not remove)
command = x+y
time = 1

;-| Dir + Button |---------------------------------------------------------
[Command]
name = "down_a"
command = /$D,a
time = 1

[Command]
name = "down_b"
command = /$D,b
time = 1

;-| Single Button |---------------------------------------------------------
[Command]
name = "a"
command = a
time = 1

[Command]
name = "b"
command = b
time = 1

[Command]
name = "c"
command = c
time = 1

[Command]
name = "x"
command = x
time = 1

[Command]
name = "y"
command = y
time = 1

[Command]
name = "z"
command = z
time = 1

[Command]
name = "start"
command = s
time = 1

;-| Hold Dir |--------------------------------------------------------------
[Command]
name = "holdfwd";Required (do not remove)
command = /$F
time = 1

[Command]
name = "holdback";Required (do not remove)
command = /$B
time = 1

[Command]
name = "holdup" ;Required (do not remove)
command = /$U
time = 1

[Command]
name = "holddown";Required (do not remove)
command = /$D
time = 1

;power 1
name = "holdb"
command = /$b
time = 1

;power 2
name = "holdy"
command = /$y
time = 1

;---------------------------------------------------------------------------
; 2. State entry
; --------------
; This is where you define what commands bring you to what states.
;
; Each state entry block looks like:
;   [State -1, Label]           ;Change Label to any name you want to use to
;                               ;identify the state with.
;   type = ChangeState          ;Don't change this
;   value = new_state_number
;   trigger1 = command = command_name
;   . . .  (any additional triggers)
;
; - new_state_number is the number of the state to change to
; - command_name is the name of the command (from the section above)
; - Useful triggers to know:
;   - statetype
;       S, C or A : current state-type of player (stand, crouch, air)
;   - ctrl
;       0 or 1 : 1 if player has control. Unless "interrupting" another
;                move, you'll want ctrl = 1
;   - stateno
;       number of state player is in - useful for "move interrupts"
;   - movecontact
;       0 or 1 : 1 if player's last attack touched the opponent
;                useful for "move interrupts"
;
; Note: The order of state entry is important.
;   State entry with a certain command must come before another state
;   entry with a command that is the subset of the first.
;   For example, command "fwd_a" must be listed before "a", and
;   "fwd_ab" should come before both of the others.
;
; For reference on triggers, see CNS documentation.
;
; Just for your information (skip if you're not interested):
; This part is an extension of the CNS. "State -1" is a special state
; that is executed once every game-tick, regardless of what other state
; you are in.


; Don't remove the following line. It's required by the CMD standard.
[Statedef -1]

;===========================================================================
;---------------------------------------------------------------------------
;fatal
[State -1, rockette]
type = ChangeState
value = 3300
triggerall = command = "fatal"
triggerall = power >= 3000
triggerall = life <= 250
trigger1 = statetype != A
trigger1 = ctrl

;---------------------------------------------------------------------------
;super mic
[State -1, super mic]
type = ChangeState
value = 3000
triggerall = command = "mic"
triggerall = power >= 1000
triggerall = numhelper(3110)=0
trigger1 = statetype != A
trigger1 = ctrl

;---------------------------------------------------------------------------
;puppy army
[State -1, puppy army]
type = ChangeState
value = 3100
triggerall = command = "puppy"
triggerall = power >= 1000
triggerall = numhelper(3110)=0
trigger1 = statetype != A
trigger1 = ctrl

;---------------------------------------------------------------------------
;rockette
[State -1, rockette]
type = ChangeState
value = 3200
triggerall = command = "rockette"
triggerall = power >= 1000
trigger1 = statetype != A
trigger1 = ctrl

;---------------------------------------------------------------------------
;---------------------------------------------------------------------------
;light cell
[State -1, Light cell]
type = ChangeState
value = 1000
triggerall = command = "cellx"
triggerall = statetype != A
trigger1 = ctrl
trigger2 = (stateno = 200)||(stateno = 205)||(stateno = 210)
trigger2 = movecontact
trigger3 = (stateno = 230)||(stateno = 235)||(stateno = 240)
trigger3 = movecontact
trigger4 = (stateno = 400)||(stateno = 405)||(stateno = 410)
trigger4 = movecontact
trigger5 = (stateno = 430)||(stateno = 435)
trigger5 = movecontact

;---------------------------------------------------------------------------
;medium cell
[State -1, medium cell]
type = ChangeState
value = 1001
triggerall = command = "celly"
triggerall = statetype != A
trigger1 = ctrl
trigger2 = (stateno = 200)||(stateno = 205)||(stateno = 210)
trigger2 = movecontact
trigger3 = (stateno = 230)||(stateno = 235)||(stateno = 240)
trigger3 = movecontact
trigger4 = (stateno = 400)||(stateno = 405)||(stateno = 410)
trigger4 = movecontact
trigger5 = (stateno = 430)||(stateno = 435)
trigger5 = movecontact

;---------------------------------------------------------------------------
;strong cell
[State -1, strong cell]
type = ChangeState
value = 1002
triggerall = command = "cellz"
triggerall = statetype != A
trigger1 = ctrl
trigger2 = (stateno = 200)||(stateno = 205)||(stateno = 210)
trigger2 = movecontact
trigger3 = (stateno = 230)||(stateno = 235)||(stateno = 240)
trigger3 = movecontact
trigger4 = (stateno = 400)||(stateno = 405)||(stateno = 410)
trigger4 = movecontact
trigger5 = (stateno = 430)||(stateno = 435)
trigger5 = movecontact

;---------------------------------------------------------------------------
;---------------------------------------------------------------------------
;light twist
[State -1, Light twist]
type = ChangeState
value = 1100
triggerall = command = "twistx"
triggerall = statetype != A
trigger1 = ctrl
trigger2 = (stateno = 200)||(stateno = 205)||(stateno = 210)
trigger2 = movecontact
trigger3 = (stateno = 230)||(stateno = 235)||(stateno = 240)
trigger3 = movecontact
trigger4 = (stateno = 400)||(stateno = 405)||(stateno = 410)
trigger4 = movecontact
trigger5 = (stateno = 430)||(stateno = 435)
trigger5 = movecontact

;---------------------------------------------------------------------------
;medium twist
[State -1, medium twist]
type = ChangeState
value = 1101
triggerall = command = "twisty"
triggerall = statetype != A
trigger1 = ctrl
trigger2 = (stateno = 200)||(stateno = 205)||(stateno = 210)
trigger2 = movecontact
trigger3 = (stateno = 230)||(stateno = 235)||(stateno = 240)
trigger3 = movecontact
trigger4 = (stateno = 400)||(stateno = 405)||(stateno = 410)
trigger4 = movecontact
trigger5 = (stateno = 430)||(stateno = 435)
trigger5 = movecontact

;---------------------------------------------------------------------------
;strong twist
[State -1, strong twist]
type = ChangeState
value = 1102
triggerall = command = "twistz"
triggerall = statetype != A
trigger1 = ctrl
trigger2 = (stateno = 200)||(stateno = 205)||(stateno = 210)
trigger2 = movecontact
trigger3 = (stateno = 230)||(stateno = 235)||(stateno = 240)
trigger3 = movecontact
trigger4 = (stateno = 400)||(stateno = 405)||(stateno = 410)
trigger4 = movecontact
trigger5 = (stateno = 430)||(stateno = 435)
trigger5 = movecontact

;---------------------------------------------------------------------------
;---------------------------------------------------------------------------
;light multi-kicks
[State -1, Light multi-kicks]
type = ChangeState
value = 1200
triggerall = command = "multia"
triggerall = statetype != A
trigger1 = ctrl
trigger2 = (stateno = 200)||(stateno = 205)||(stateno = 210)
trigger2 = movecontact
trigger3 = (stateno = 230)||(stateno = 235)||(stateno = 240)
trigger3 = movecontact
trigger4 = stateno = 440
trigger4 = movecontact

;---------------------------------------------------------------------------
;medium multi-kicks
[State -1, medium multi-kicks]
type = ChangeState
value = 1201
triggerall = command = "multib"
triggerall = statetype != A
trigger1 = ctrl
trigger2 = (stateno = 200)||(stateno = 205)||(stateno = 210)
trigger2 = movecontact
trigger3 = (stateno = 230)||(stateno = 235)||(stateno = 240)
trigger3 = movecontact
trigger4 = stateno = 440
trigger4 = movecontact

;---------------------------------------------------------------------------
;strong multi-kicks
[State -1, strong multi-kicks]
type = ChangeState
value = 1202
triggerall = command = "multic"
triggerall = statetype != A
trigger1 = ctrl
trigger2 = (stateno = 200)||(stateno = 205)||(stateno = 210)
trigger2 = movecontact
trigger3 = (stateno = 230)||(stateno = 235)||(stateno = 240)
trigger3 = movecontact
trigger4 = stateno = 440
trigger4 = movecontact

;---------------------------------------------------------------------------
;---------------------------------------------------------------------------
;light rising kick
[State -1, light rising kick]
type = ChangeState
value = 1300
triggerall = command = "risinga"
triggerall = statetype != A
trigger1 = ctrl
trigger2 = (stateno = 200)||(stateno = 205)||(stateno = 210)
trigger2 = movecontact
trigger3 = (stateno = 230)||(stateno = 235)||(stateno = 240)
trigger3 = movecontact
trigger4 = stateno = 440
trigger4 = movecontact

;---------------------------------------------------------------------------
;medium rising kick
[State -1, medium rising kick]
type = ChangeState
value = 1301
triggerall = command = "risingb"
triggerall = statetype != A
trigger1 = ctrl
trigger2 = (stateno = 200)||(stateno = 205)||(stateno = 210)
trigger2 = movecontact
trigger3 = (stateno = 230)||(stateno = 235)||(stateno = 240)
trigger3 = movecontact
trigger4 = stateno = 440
trigger4 = movecontact

;---------------------------------------------------------------------------
;strong rising kick
[State -1, strong rising kick]
type = ChangeState
value = 1302
triggerall = command = "risingc"
triggerall = statetype != A
trigger1 = ctrl
trigger2 = (stateno = 200)||(stateno = 205)||(stateno = 210)
trigger2 = movecontact
trigger3 = (stateno = 230)||(stateno = 235)||(stateno = 240)
trigger3 = movecontact
trigger4 = stateno = 440
trigger4 = movecontact

;===========================================================================
;---------------------------------------------------------------------------
;Run Fwd
;_bV
[State -1, Run Fwd]
type = ChangeState
value = 100
trigger1 = command = "FF"
trigger1 = statetype != A
trigger1 = ctrl

;---------------------------------------------------------------------------
;Run Back
;ރ_bV
[State -1, Run Back]
type = ChangeState
value = 105
trigger1 = command = "BB"
trigger1 = statetype != A
trigger1 = ctrl

;---------------------------------------------------------------------------
;Kung Fu Throw
;
[State -1, Kung Fu Throw]
type = ChangeState
value = 800
triggerall = command = "z"
triggerall = statetype = S
triggerall = ctrl
triggerall = stateno != 100
trigger1 = command = "holdfwd"
trigger1 = p2bodydist X < 3
trigger1 = (p2statetype = S) || (p2statetype = C)
trigger1 = p2movetype != H
trigger2 = command = "holdback"
trigger2 = p2bodydist X < 5
trigger2 = (p2statetype = S) || (p2statetype = C)
trigger2 = p2movetype != H


;===========================================================================
;---------------------------------------------------------------------------
;Stand Light Punch
[State -1, Stand Light Punch]
type = ChangeState
value = 200
triggerall = command = "x"
triggerall = command != "holddown"
trigger1 = statetype = S
trigger1 = ctrl
trigger2 = stateno = 200
trigger2 = time > 6
trigger3 = stateno = 230 && movecontact

;---------------------------------------------------------------------------
;Stand medium Punch
[State -1, Stand medium Punch]
type = ChangeState
value = 205
triggerall = command = "y"
triggerall = command != "holddown"
trigger1 = statetype = S
trigger1 = ctrl
trigger2 = (stateno = 200) || (stateno = 230)
trigger2 = movecontact

;---------------------------------------------------------------------------
;Stand Strong Punch
[State -1, Stand Strong Punch]
type = ChangeState
value = 210
triggerall = command = "z"
triggerall = command != "holddown"
trigger1 = statetype = S
trigger1 = ctrl
trigger2 = (stateno = 200) || (stateno = 205) || (stateno = 230) || (stateno = 235)
trigger2 = movecontact

;---------------------------------------------------------------------------
;Stand Light Kick
;LbN
[State -1, Stand Light Kick]
type = ChangeState
value = 230
triggerall = command = "a"
triggerall = command != "holddown"
trigger1 = statetype = S
trigger1 = ctrl
trigger2 = stateno = 230 && time > 9
trigger3 = stateno = 200 && movecontact


;---------------------------------------------------------------------------
;Standing Medium Kick
;LbN
[State -1, Standing Strong Kick]
type = ChangeState
value = 235
triggerall = command = "b"
triggerall = command != "holddown"
trigger1 = statetype = S
trigger1 = ctrl
trigger2 = (stateno = 200) || (stateno = 230)
trigger2 = movecontact

;---------------------------------------------------------------------------
;Standing Strong Kick
;LbN
[State -1, Standing Strong Kick]
type = ChangeState
value = 240
triggerall = command = "c"
triggerall = command != "holddown"
trigger1 = statetype = S
trigger1 = ctrl
trigger2 = (stateno = 200) || (stateno = 205) || (stateno = 230) || (stateno = 235)
trigger2 = movecontact

;---------------------------------------------------------------------------
;Taunt
;
[State -1, Taunt]
type = ChangeState
value = 199
triggerall = command = "start"
trigger1 = statetype != A
trigger1 = ctrl

;---------------------------------------------------------------------------
;Crouching Light Punch
;Ⴊݎp`
[State -1, Crouching Light Punch]
type = ChangeState
value = 400
triggerall = command = "x"
triggerall = command = "holddown"
trigger1 = statetype = C
trigger1 = ctrl
trigger2 = stateno = 430
trigger2 = movecontact

;---------------------------------------------------------------------------
;Crouching Medium Punch
[State -1, Crouching Medium Punch]
type = ChangeState
value = 405
triggerall = command = "y"
triggerall = command = "holddown"
trigger1 = statetype = C
trigger1 = ctrl
trigger2 = (stateno = 400) || (stateno = 430)
trigger2 = movecontact

;---------------------------------------------------------------------------
;Crouching Strong Punch
;Ⴊ݋p`
[State -1, Crouching Strong Punch]
type = ChangeState
value = 410
triggerall = command = "z"
triggerall = command = "holddown"
trigger1 = statetype = C
trigger1 = ctrl
trigger2 = (stateno = 400) || (stateno = 405) || (stateno = 430) || (stateno = 435)
trigger2 = movecontact

;---------------------------------------------------------------------------
;Crouching Light Kick
;ႪݎLbN
[State -1, Crouching Light Kick]
type = ChangeState
value = 430
triggerall = command = "a"
triggerall = command = "holddown"
trigger1 = statetype = C
trigger1 = ctrl
trigger2 = stateno = 400
trigger2 = movecontact

;---------------------------------------------------------------------------
;Crouching Medium Kick
;Ⴊ݋LbN
[State -1, Crouching Strong Kick]
type = ChangeState
value = 435
triggerall = command = "b"
triggerall = command = "holddown"
trigger1 = statetype = C
trigger1 = ctrl
trigger2 = (stateno = 400) || (stateno = 430)
trigger2 = movecontact

;---------------------------------------------------------------------------
;Crouching Strong Kick
;Ⴊ݋LbN
[State -1, Crouching Strong Kick]
type = ChangeState
value = 440
triggerall = command = "c"
triggerall = command = "holddown"
trigger1 = statetype = C
trigger1 = ctrl
trigger2 = (stateno = 400) || (stateno = 405) || (stateno = 430) || (stateno = 435)
trigger2 = movecontact

;---------------------------------------------------------------------------
;Jump Light Punch
;󒆎p`
[State -1, Jump Light Punch]
type = ChangeState
value = 600
triggerall = command = "x"
trigger1 = statetype = A
trigger1 = ctrl
trigger2 = stateno = 600
trigger2 = statetime >= 7
trigger3 = (stateno = 630)
trigger3 = movecontact

;---------------------------------------------------------------------------
;Jump medium Punch
[State -1, Jump Strong Punch]
type = ChangeState
value = 605
triggerall = command = "y"
trigger1 = statetype = A
trigger1 = ctrl
trigger2 = (stateno = 600)||(stateno = 630)
trigger2 = movecontact

;---------------------------------------------------------------------------
;Jump Strong Punch
[State -1, Jump Strong Punch]
type = ChangeState
value = 610
triggerall = command = "z"
trigger1 = statetype = A
trigger1 = ctrl
trigger2 = (stateno = 600)||(stateno = 605)||(stateno = 630)||(stateno = 635)
trigger2 = movecontact
;---------------------------------------------------------------------------
;Jump Light Kick
[State -1, Jump Light Kick]
type = ChangeState
value = 630
triggerall = command = "a"
trigger1 = statetype = A
trigger1 = ctrl
trigger2 = (stateno = 600)
trigger2 = movecontact

;---------------------------------------------------------------------------
;Jump medium Kick
[State -1, Jump medium Kick]
type = ChangeState
value = 635
triggerall = command = "b"
trigger1 = statetype = A
trigger1 = ctrl
trigger2 = (stateno = 600)||(stateno = 630)
trigger2 = movecontact

;---------------------------------------------------------------------------
;Jump Strong Kick
;󒆋LbN
[State -1, Jump Strong Kick]
type = ChangeState
value = 640
triggerall = command = "c"
trigger1 = statetype = A
trigger1 = ctrl
trigger2 = (stateno = 600)||(stateno = 605)||(stateno = 630)||(stateno = 635)
trigger2 = movecontact


;-------------------------------------------------------------------
;-------------------------------------------------------------------
;-----AI------------------------------------------------------------
;-------------------------------------------------------------------
;-------------------------------------------------------------------

;Movimientos basicos
;-------------------

;run fwd
[State -1]
type = ChangeState
triggerall = var(24)=1 && roundstate=2
triggerall = statetype != a && ctrl && stateno!=100
trigger1 = p2dist x > 60 && random < 20 && enemynear, movetype !=a
value = 100

;run back
[State -1]
type = ChangeState
triggerall = var(24)=1 && roundstate=2 && statetype != a && ctrl
trigger1 = enemynear, movetype = a && p2dist x<= 60 && random <5
value = 105

;GUARD
;-----

[State -1]
type = ChangeState
trigger1 = var(24) && roundstate=2 && ctrl
trigger1 = !(enemynear,hitdefattr=SCA,AT) && inguarddist
trigger1 = (stateno!=[120,155]) && random < 250
value = 120


;ATAQUE BASICO
;-------------

;primer ataque ST
[State -1]
type = ChangeState
triggerall = var(24)=1 && roundstate=2 && statetype !=a
triggerall = (p2statetype!=L)
trigger1 = p2dist x <= 60 && random <70 && ctrl
;combo chain 1
trigger2 = p2dist x <= 60 && random <300
trigger2 = (stateno = 200)||(stateno = 230)
trigger2 = movecontact
value = ifelse(random<200&&stateno!=200,200,ifelse(random<200,205,ifelse(random<250,210,ifelse(random<333&&stateno!=230,230,ifelse(random<500,235,240)))))

[State -1]
;combo chain para mediums
type = ChangeState
triggerall = var(24)=1 && roundstate=2 && statetype !=a
triggerall = (p2statetype!=L)
trigger1 = p2dist x <= 60 && random <200
trigger1 = (stateno = 205)||(stateno = 235)
trigger1 = movecontact
value = ifelse(random<500,210,240)


;primer ataque CROUCH
[State -1]
type = ChangeState
triggerall = var(24)=1 && roundstate=2 && statetype !=a
triggerall = (p2statetype!=L)
trigger1 = p2dist x <= 50 && random <100 && ctrl
;combo chain 1
trigger2 = p2dist x <= 50 && random <300
trigger2 = (stateno = 400)||(stateno = 430)
trigger2 = movecontact
value = ifelse(random<200&&stateno!=400,400,ifelse(random<200,405,ifelse(random<250,410,ifelse(random<333&&stateno!=430,430,ifelse(random<500,435,440)))))

[State -1]
;combo chain para mediums
type = ChangeState
triggerall = var(24)=1 && roundstate=2 && statetype !=a
triggerall = (p2statetype!=L)
trigger1 = p2dist x <= 60 && random <200
trigger1 = (stateno = 405)||(stateno = 435)
trigger1 = movecontact
value = ifelse(random<500,410,440)


;primer ataque JP
[State -1]
type = ChangeState
triggerall = var(24)=1 && roundstate=2 && statetype = a
triggerall = (p2statetype!=L)
trigger1 = p2dist x <= 80 && random <150 && ctrl
;combo chain 1
trigger2 = p2dist x <= 80 && random <300
trigger2 = (stateno = 600)||(stateno = 630)
trigger2 = movecontact
value = ifelse(random<200&&stateno!=600,600,ifelse(random<200,605,ifelse(random<250,610,ifelse(random<333&&stateno!=630,630,ifelse(random<500,635,640)))))

[State -1]
;combo chain para mediums
type = ChangeState
triggerall = var(24)=1 && roundstate=2 && statetype = a
triggerall = (p2statetype!=L)
trigger1 = p2dist x <= 80 && random <200
trigger1 = (stateno = 605)||(stateno = 635)
trigger1 = movecontact
value = ifelse(random<500,610,640)


;agarre
[State -1, Kung Fu Throw]
type = ChangeState
triggerall = var(24)=1 && roundstate=2 && statetype !=a
triggerall = ctrl && (p2statetype!=L)
triggerall = stateno != 100
trigger1 = p2bodydist X < 5
trigger1 = (p2statetype = S) || (p2statetype = C)
trigger1 = p2movetype != H
trigger1 = enemynear, pos y > -2 && random < 250
value = 800


;SPECIALS
;--------

;cells
[State -1]
type = ChangeState
triggerall = var(24)=1 && roundstate=2 && statetype !=a
triggerall = (p2stateno!=[120,155]) && (p2statetype!=L)
trigger1 = p2dist x >= 70 && ctrl
trigger1 = random < (ifelse(life>250,5,25))
trigger2 = (stateno = 200)||(stateno = 205)||(stateno = 210)
trigger2 = movecontact && random < 150
trigger3 = (stateno = 230)||(stateno = 235)||(stateno = 240)
trigger3 = movecontact && random < 150
trigger4 = (stateno = 400)||(stateno = 405)||(stateno = 410)
trigger4 = movecontact && random < 150
trigger5 = (stateno = 430)||(stateno = 435)
trigger5 = movecontact && random < 150
;cuando p2 salta
trigger6 = enemynear, statetype = a
trigger6 = p2dist x <= 150 && ctrl && random < 30
value = ifelse(random<333,1000,ifelse(random<500,1001,1002))

;twists
[State -1]
type = ChangeState
triggerall = var(24)=1 && roundstate=2 && statetype !=a
triggerall = (p2stateno!=[120,155]) && (p2statetype!=L)
trigger1 = p2dist x <= 120 && ctrl && random < 5
;combo chain 1
trigger2 = (stateno = 200)||(stateno = 205)||(stateno = 210)
trigger2 = movecontact && random < 150
trigger3 = (stateno = 230)||(stateno = 235)||(stateno = 240)
trigger3 = movecontact && random < 150
trigger4 = (stateno = 400)||(stateno = 405)||(stateno = 410)
trigger4 = movecontact && random < 150
trigger5 = (stateno = 430)||(stateno = 435)
trigger5 = movecontact && random < 150
value = ifelse(random<333,1100,ifelse(random<500,1101,1102))

;multikicks
[State -1]
type = ChangeState
triggerall = var(24)=1 && roundstate=2 && statetype !=a
triggerall = (p2stateno!=[120,155]) && (p2statetype!=L)
trigger1 = p2dist x <= 120 && ctrl && random < 5
;combo chain 1
trigger2 = (stateno = 200)||(stateno = 205)||(stateno = 210)
trigger2 = movecontact && random < 150
trigger3 = (stateno = 230)||(stateno = 235)||(stateno = 240)
trigger3 = movecontact && random < 150
trigger4 = stateno = 440
trigger4 = movecontact && random < 150
value = ifelse(random<333,1200,ifelse(random<500,1201,1202))

;rising kicks
[State -1]
type = ChangeState
triggerall = var(24)=1 && roundstate=2 && statetype !=a
triggerall = (p2stateno!=[120,155]) && (p2statetype!=L)
trigger1 = p2dist x <= 120 && ctrl && random < 5
;combo chain 1
trigger2 = (stateno = 200)||(stateno = 205)||(stateno = 210)
trigger2 = movecontact && random < 150
trigger3 = (stateno = 230)||(stateno = 235)||(stateno = 240)
trigger3 = movecontact && random < 150
trigger4 = stateno = 440
trigger4 = movecontact && random < 150
;cuando p2 salta
trigger3 = enemynear, statetype = a
trigger3 = p2dist x <= 150 && ctrl && random < 30
value = ifelse(random<333,1300,ifelse(random<500,1301,1302))


;HYPERMOVES
;----------

;supermic && puppy army
[State -1]
type = ChangeState
triggerall = var(24)=1 && roundstate=2 && statetype !=a && power >= 1000
triggerall = (p2stateno!=[120,155]) && (p2statetype!=L)
trigger1 = p2dist x >= 70 && ctrl && random < 4
value = ifelse(random<500,3000,3100)

;rockette
[State -1]
type = ChangeState
triggerall = var(24)=1 && roundstate=2 && statetype !=a && power >= 1000
triggerall = (p2stateno!=[120,155]) && (p2statetype!=L)
trigger1 = p2dist x <= 150 && ctrl && random < 6
value = 3200

;fatal move
[State -1, fatal move]
type = ChangeState
triggerall = var(24)=1 && roundstate=2 && statetype !=a
triggerall = power >= 3000 && life <= 250 && life !=0 && alive
trigger1 = p2dist x <= 120 && ctrl && random < 35 && (p2statetype!=L)
value = 3300

